import request from '@/utils/request'

// 查询项目上报列表
export function listReport(query) {
  return request({
    url: '/bmProjectReport/report/list',
    method: 'get',
    params: query
  })
}

// 查询项目上报详细
export function getReport(id) {
  return request({
    url: '/bmProjectReport/report/' + id,
    method: 'get'
  })
}

// 新增项目上报
export function addReport(data) {
  return request({
    url: '/bmProjectReport/report',
    method: 'post',
    data: data
  })
}

// 修改项目上报
export function updateReport(data) {
  return request({
    url: '/projectReferral/referral/edit',
    method: 'post',
    data: data
  })
}

// 删除项目上报
export function delReport(id) {
  return request({
    url: '/bmProjectReport/report/' + id,
    method: 'delete'
  })
}

// 导出项目上报
export function exportReport(query) {
  return request({
    url: '/bmProjectReport/report/export',
    method: 'get',
    params: query
  })
}
